import * as RxJS from 'rxjs';
export declare type Undux<State extends object> = {
    [K in keyof State]: {
        key: K;
        previousValue: State[K];
        value: State[K];
    };
};
export interface Store<State extends object> {
    get<K extends keyof State>(key: K): State[K];
    set<K extends keyof State>(key: K): (value: State[K]) => void;
    on<K extends keyof State>(key: K): RxJS.Observable<State[K]>;
    onAll(): RxJS.Observable<Undux<State>[keyof State]>;
    getState(): Readonly<State>;
}
export declare class StoreSnapshot<State extends object> implements Store<State> {
    private state;
    private storeDefinition;
    constructor(state: State, storeDefinition: StoreDefinition<State>);
    get<K extends keyof State>(key: K): State[K];
    set<K extends keyof State>(key: K): { readonly [K_1 in keyof State]: (value: State[K_1]) => void; }[K];
    on<K extends keyof State>(key: K): RxJS.Observable<State[K]>;
    onAll(): RxJS.Observable<Undux<State>[keyof State]>;
    getState(): Readonly<State>;
}
export declare type Options = {
    isDevMode: boolean;
};
export declare class StoreDefinition<State extends object> implements Store<State> {
    private storeSnapshot;
    private alls;
    private emitter;
    private setters;
    constructor(state: State, options: Options);
    on<K extends keyof State>(key: K): RxJS.Observable<State[K]>;
    onAll(): RxJS.Observable<Undux<State>[keyof State]>;
    get<K extends keyof State>(key: K): State[K];
    set<K extends keyof State>(key: K): { readonly [K_1 in keyof State]: (value: State[K_1]) => void; }[K];
    getCurrentSnapshot(): StoreSnapshot<State>;
    toStore(): Store<State>;
    getState(): Readonly<State>;
}
export declare function createStore<State extends object>(initialState: State, options?: Options): StoreDefinition<State>;
export declare type Plugin<State extends object> = (store: StoreDefinition<State>) => StoreDefinition<State>;
export * from './plugins/withLogger';
export * from './plugins/withReduxDevtools';
export * from './react';
